[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,69 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
*
|
||||
* @brief Experiment with local context nesting
|
||||
*
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
int main()
|
||||
{
|
||||
stackable_ctx ctx;
|
||||
|
||||
int array[1024];
|
||||
for (size_t i = 0; i < 1024; i++)
|
||||
{
|
||||
array[i] = 1 + i * i;
|
||||
}
|
||||
|
||||
auto lA = ctx.logical_data(array).set_symbol("A");
|
||||
|
||||
// repeat : {tmp = a; tmp*=2; a+=tmp}
|
||||
for (size_t iter = 0; iter < 10; iter++)
|
||||
{
|
||||
stackable_ctx::graph_scope_guard graph{ctx}; // RAII: automatic push/pop (lock_guard style)
|
||||
|
||||
auto tmp = ctx.logical_data(lA.shape()).set_symbol("tmp");
|
||||
|
||||
ctx.parallel_for(tmp.shape(), tmp.write(), lA.read())->*[] __device__(size_t i, auto tmp, auto a) {
|
||||
tmp(i) = a(i);
|
||||
};
|
||||
|
||||
ctx.parallel_for(tmp.shape(), tmp.rw())->*[] __device__(size_t i, auto tmp) {
|
||||
tmp(i) *= 2;
|
||||
};
|
||||
|
||||
ctx.parallel_for(lA.shape(), tmp.read(), lA.rw())->*[] __device__(size_t i, auto tmp, auto a) {
|
||||
a(i) += tmp(i);
|
||||
};
|
||||
|
||||
// ctx.pop() is called automatically when 'graph' goes out of scope
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
|
||||
// Verify the array has been updated correctly by the write-back mechanism
|
||||
// Each iteration transforms each element: a_new = a_old + 2 * a_old = 3 * a_old
|
||||
// Starting from array[i] = 1 + i*i, after 10 iterations:
|
||||
// array[i] = 3^10 * (1 + i*i)
|
||||
constexpr int pow3_10 = 59049; // 3^10
|
||||
|
||||
for (size_t i = 0; i < 1024; i++)
|
||||
{
|
||||
int expected = pow3_10 * (1 + static_cast<int>(i * i));
|
||||
EXPECT(array[i] == expected);
|
||||
}
|
||||
}
|
||||
Reference in New Issue
Block a user